# PythonLib aRTist

Python library and scripts to control the BAM X-ray simulation tool "aRTist" remotely and automatically.

Please refer to the **[documentation](https://bamresearch.github.io/artistlib/)** to get started.

For more information on aRTist see its **[website](https://www.artist.bam.de)** and its **[online guide](https://bamresearch.github.io/aRTist-handbook/)**.
